@@ -13,7 +13,7 @@ use AnyEvent::Filesys::Notify::Event;
 use Carp;
 use Try::Tiny;
 
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 my $AEFN = 'AnyEvent::Filesys::Notify';
 
 has dirs         => ( is => 'ro', isa => 'ArrayRef[Str]', required => 1 );
@@ -57,7 +57,8 @@ sub _process_events {
 
     # Some backends need to add files (KQueue) or directories (Inotify2) to the
     # watch list after they are created. Give them a chance to do that here.
-    $self->_add_created(@events) if $self->can('_add_created');
+    $self->_process_events_for_backend(@events)
+      if $self->can('_process_events_for_backend');
 
     $self->cb->(@events) if @events;
 
@@ -241,7 +242,7 @@ AnyEvent::Filesys::Notify - An AnyEvent compatible module to monitor files/direc
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 STATUS
 
