@@ -10,7 +10,7 @@ use Linux::Inotify2;
 use Carp;
 use Path::Iterator::Rule;
 
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 
 # use Scalar::Util qw(weaken);  # Attempt to address RT#57104, but alas...
 
@@ -101,7 +101,7 @@ sub _parse_events {
 
 # Need to add newly created sub-dirs to the watch list.
 # This is done after filtering. So entire dirs can be ignored efficiently;
-sub _add_created {
+sub _process_events_for_backend {
     my ( $self, @events ) = @_;
 
     for my $event (@events) {
@@ -128,7 +128,7 @@ AnyEvent::Filesys::Notify::Role::Inotify2 - Use Linux::Inotify2 to watch for cha
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 CONTRIBUTORS
 
